@@ -17,4 +17,8 @@ from __future__ import absolute_import
 from .core import *
 from .networks import *
 from .dataset_prepare import *
-from .download_utils import *
\ No newline at end of file
+from .download_utils import *
+from .prettyloss import *
+from . import nnets
+from . import model_metrics
+from . import xai
\ No newline at end of file
